add — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# add

poscar_modify.add(element: str, position: List[float] | np.nadarray, cartesian: bool = False)

  Adds a single atom to the Poscar object.

  Parameters:

    - element (str) – a string with the atomic specie, e.g. ‘Cu’

    - position (List[float] | np.nadarray) – [X, Y, Z]

    - cartesian (bool) – are the positions in Cartesian (True) or direct coordiantes (False)? Default is False